@@ -1,4 +1,4 @@
-from .normal import cholesky_precision, log_normal, sample_normal
+from .normal import cholesky_precision, covariance, log_normal, sample_normal
 from .types import CovarianceType
 from .utils import covariance_dim, covariance_shape
 
@@ -6,6 +6,7 @@ __all__ = [
     "cholesky_precision",
     "log_normal",
     "sample_normal",
+    "covariance",
     "CovarianceType",
     "covariance_dim",
     "covariance_shape",
